==> mule-module-extensions-support-4.6.23-20250909.083402-13-sources.jar: org/mule/runtime/module/extension/internal/runtime/connectivity/oauth/clientcredentials/ClientCredentialsConfig.java <==
/*
 * Copyright 2023 Salesforce, Inc. All rights reserved.
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.runtime.module.extension.internal.runtime.connectivity.oauth.clientcredentials;

import static java.util.Optional.ofNullable;

import org.mule.runtime.extension.api.connectivity.oauth.ClientCredentialsGrantType;
import org.mule.runtime.extension.api.security.CredentialsPlacement;
import org.mule.runtime.module.extension.internal.runtime.connectivity.oauth.CustomOAuthParameters;
import org.mule.runtime.module.extension.internal.runtime.connectivity.oauth.OAuthConfig;
import org.mule.runtime.module.extension.internal.runtime.connectivity.oauth.OAuthObjectStoreConfig;

import java.lang.reflect.Field;
import java.util.Map;
import java.util.Optional;

/**
 * {@link OAuthConfig} specialization for client credentials grant type
 *
 * @since 4.2.1
 */
public class ClientCredentialsConfig extends OAuthConfig<ClientCredentialsGrantType> {

  private static final String CONFIG_ID_SEPARATOR = "//";

  private final String clientId;
  private final String clientSecret;
  private final String tokenUrl;
  private final String scope;
  private final CredentialsPlacement credentialsPlacement;
  private final ClientCredentialsGrantType grantType;
  private final String configIdentifier;

  public ClientCredentialsConfig(String ownerConfigName,
                                 Optional<OAuthObjectStoreConfig> storeConfig,
                                 CustomOAuthParameters customOAuthParameters,
                                 Map<Field, String> parameterExtractors,
                                 String clientId,
                                 String clientSecret,
                                 String tokenUrl,
                                 String scope,
                                 CredentialsPlacement credentialsPlacement,
                                 ClientCredentialsGrantType grantType) {
    super(ownerConfigName, storeConfig, customOAuthParameters, parameterExtractors);
    this.clientId = clientId;
    this.clientSecret = clientSecret;
    this.tokenUrl = tokenUrl;
    this.scope = scope;
    this.credentialsPlacement = credentialsPlacement;
    this.grantType = grantType;
    this.configIdentifier = generateConfigIdentifier();
  }

  private String generateConfigIdentifier() {
    StringBuilder configIdentifierBuilder = new StringBuilder();
    configIdentifierBuilder.append(getOwnerConfigName());
    configIdentifierBuilder.append(CONFIG_ID_SEPARATOR);
    configIdentifierBuilder.append(getClientId());
    configIdentifierBuilder.append(CONFIG_ID_SEPARATOR);
    configIdentifierBuilder.append(getClientSecret());
    configIdentifierBuilder.append(CONFIG_ID_SEPARATOR);
    configIdentifierBuilder.append(getTokenUrl());
    configIdentifierBuilder.append(CONFIG_ID_SEPARATOR);
    configIdentifierBuilder.append(getScope().orElse(""));
    return configIdentifierBuilder.toString();
  }

  public String getClientId() {
    return clientId;
  }

  public String getClientSecret() {
    return clientSecret;
  }

  public String getTokenUrl() {
    return tokenUrl;
  }

  public CredentialsPlacement getCredentialsPlacement() {
    return credentialsPlacement;
  }

  public Optional<String> getScope() {
    return ofNullable(scope);
  }

  public String getConfigIdentifier() {
    return configIdentifier;
  }

  @Override
  public ClientCredentialsGrantType getGrantType() {
    return grantType;
  }
}

==> mule-module-extensions-support-4.11.0-20251119.220312-167-sources.jar: org/mule/runtime/module/extension/internal/runtime/connectivity/oauth/clientcredentials/ClientCredentialsConfig.java <==
/*
 * Copyright 2023 Salesforce, Inc. All rights reserved.
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.runtime.module.extension.internal.runtime.connectivity.oauth.clientcredentials;

import static java.util.Optional.ofNullable;

import org.mule.runtime.api.tls.TlsContextFactory;
import org.mule.runtime.extension.api.connectivity.oauth.ClientCredentialsGrantType;
import org.mule.runtime.extension.api.security.CredentialsPlacement;
import org.mule.runtime.http.api.client.proxy.ProxyConfig;
import org.mule.runtime.module.extension.internal.runtime.connectivity.oauth.CustomOAuthParameters;
import org.mule.runtime.module.extension.internal.runtime.connectivity.oauth.OAuthConfig;
import org.mule.runtime.module.extension.internal.runtime.connectivity.oauth.OAuthObjectStoreConfig;

import java.lang.reflect.Field;
import java.util.Map;
import java.util.Optional;

/**
 * {@link OAuthConfig} specialization for client credentials grant type
 *
 * @since 4.2.1
 */
public class ClientCredentialsConfig extends OAuthConfig<ClientCredentialsGrantType> {

  private static final String CONFIG_ID_SEPARATOR = "//";

  private final String clientId;
  private final String clientSecret;
  private final String tokenUrl;
  private final String scope;
  private final CredentialsPlacement credentialsPlacement;
  private final ClientCredentialsGrantType grantType;
  private final String configIdentifier;
  private final TlsContextFactory tlsContext;
  private final ProxyConfig proxyConfig;

  public ClientCredentialsConfig(String ownerConfigName,
                                 Optional<OAuthObjectStoreConfig> storeConfig,
                                 CustomOAuthParameters customOAuthParameters,
                                 Map<Field, String> parameterExtractors,
                                 String clientId,
                                 String clientSecret,
                                 String tokenUrl,
                                 String scope,
                                 CredentialsPlacement credentialsPlacement,
                                 ClientCredentialsGrantType grantType, TlsContextFactory tlsContext, ProxyConfig proxyConfig) {
    super(ownerConfigName, storeConfig, customOAuthParameters, parameterExtractors);
    this.clientId = clientId;
    this.clientSecret = clientSecret;
    this.tokenUrl = tokenUrl;
    this.scope = scope;
    this.credentialsPlacement = credentialsPlacement;
    this.grantType = grantType;
    this.configIdentifier = generateConfigIdentifier();
    this.tlsContext = tlsContext;
    this.proxyConfig = proxyConfig;
  }

  private String generateConfigIdentifier() {
    StringBuilder configIdentifierBuilder = new StringBuilder();
    configIdentifierBuilder.append(getOwnerConfigName());
    configIdentifierBuilder.append(CONFIG_ID_SEPARATOR);
    configIdentifierBuilder.append(getClientId());
    configIdentifierBuilder.append(CONFIG_ID_SEPARATOR);
    configIdentifierBuilder.append(getClientSecret());
    configIdentifierBuilder.append(CONFIG_ID_SEPARATOR);
    configIdentifierBuilder.append(getTokenUrl());
    configIdentifierBuilder.append(CONFIG_ID_SEPARATOR);
    configIdentifierBuilder.append(getScope().orElse(""));
    return configIdentifierBuilder.toString();
  }

  public String getClientId() {
    return clientId;
  }

  public String getClientSecret() {
    return clientSecret;
  }

  public String getTokenUrl() {
    return tokenUrl;
  }

  public CredentialsPlacement getCredentialsPlacement() {
    return credentialsPlacement;
  }

  public Optional<String> getScope() {
    return ofNullable(scope);
  }

  public String getConfigIdentifier() {
    return configIdentifier;
  }

  @Override
  public ClientCredentialsGrantType getGrantType() {
    return grantType;
  }

  public TlsContextFactory getTlsContext() {
    return tlsContext;
  }

  public ProxyConfig getProxyConfig() {
    return proxyConfig;
  }
}
